@@ -29,20 +29,13 @@ class AbstractProtocol(metaclass=abc.ABCMeta):
         # print(f"{'Parameter':<30}\t{'Value':<15} Unit")
         if self._protocol_id is None:
             log.error("Attempted to list commands with no protocol defined")
-            return {
-                "ERROR": ["Attempted to list commands with no protocol defined", ""]
-            }
+            return {"ERROR": ["Attempted to list commands with no protocol defined", ""]}
         result = {}
         result["_command"] = "command help"
-        result[
-            "_command_description"
-        ] = f"List available commands for protocol {str(self._protocol_id, 'utf-8')}"
+        result["_command_description"] = f"List available commands for protocol {str(self._protocol_id, 'utf-8')}"
         for command in sorted(self.COMMANDS):
             if "help" in self.COMMANDS[command]:
-                info = (
-                    self.COMMANDS[command]["description"]
-                    + self.COMMANDS[command]["help"]
-                )
+                info = self.COMMANDS[command]["description"] + self.COMMANDS[command]["help"]
             else:
                 info = self.COMMANDS[command]["description"]
             result[command] = [info, ""]
@@ -52,9 +45,7 @@ class AbstractProtocol(metaclass=abc.ABCMeta):
         return self._protocol_id
 
     def get_full_command(self, command) -> bytes:
-        log.info(
-            f"Using protocol {self._protocol_id} with {len(self.COMMANDS)} commands"
-        )
+        log.info(f"Using protocol {self._protocol_id} with {len(self.COMMANDS)} commands")
         byte_cmd = bytes(command, "utf-8")
         # calculate the CRC
         crc_high, crc_low = crc(byte_cmd)
@@ -74,9 +65,7 @@ class AbstractProtocol(metaclass=abc.ABCMeta):
                 _re = re.compile(self.COMMANDS[_command]["regex"])
                 match = _re.match(command)
                 if match:
-                    log.debug(
-                        f"Matched: {command} to: {self.COMMANDS[_command]['name']} value: {match.group(1)}"
-                    )
+                    log.debug(f"Matched: {command} to: {self.COMMANDS[_command]['name']} value: {match.group(1)}")
                     self._command_value = match.group(1)
                     return self.COMMANDS[_command]
         log.info(f"No command_defn found for {command}")
@@ -113,9 +102,7 @@ class AbstractProtocol(metaclass=abc.ABCMeta):
         if ":" in data_type:
             data_type, template = data_type.split(":", 1)
             log.debug(f"Got template {template} for {data_name} {raw_value}")
-        log.debug(
-            f"Processing data_type: {data_type} for data_name: {data_name}, raw_value {raw_value}"
-        )
+        log.debug(f"Processing data_type: {data_type} for data_name: {data_name}, raw_value {raw_value}")
         if data_type == "loop":
             log.warning("loop not implemented...")
             return [(data_name, None, data_units, extra_info)]
@@ -258,9 +245,7 @@ class AbstractProtocol(metaclass=abc.ABCMeta):
         if command_defn is None:
             # No definition, so just return the data
             len_command_defn = 0
-            log.debug(
-                f"No definition for command {command}, (splitted) raw response returned"
-            )
+            log.debug(f"No definition for command {command}, (splitted) raw response returned")
             msgs["WARNING"] = [
                 f"No definition for command {command} in protocol {self._protocol_id}",
                 "",
